changeset 1378:5955268ca3e5

Changes
author boisy
date Fri, 26 Sep 2003 18:36:44 +0000
parents 7e26b1ec9738
children 79dde72f9d96
files level2/modules/kernel/krn.asm level2/modules/kernel/krnp2.asm level2/modules/kernel/makefile
diffstat 3 files changed, 37 insertions(+), 33 deletions(-) [+]
line wrap: on
line diff
--- a/level2/modules/kernel/makefile	Fri Sep 26 17:54:49 2003 +0000
+++ b/level2/modules/kernel/makefile	Fri Sep 26 18:36:44 2003 +0000
@@ -5,8 +5,8 @@
 DEPENDS		= ./makefile
 ADDOPTS		= -e
 
-OS9P1		= os9p1
-OS9P2		= os9p2
+KERNEL		= kernel
+KERNELP2	= kernelp2
 SYSCALLS	= fallimg.asm fallram.asm falltsk.asm faproc.asm fcmpnam.asm \
 		fcpymem.asm fdatlog.asm fdelram.asm ffmodul.asm ffreehb.asm \
 		fld.asm fldabx.asm flink.asm fmove.asm fnproc.asm fprsnam.asm \
@@ -17,13 +17,13 @@
 		fid.asm fmapblk.asm fmem.asm fsend.asm fsleep.asm fsprior.asm \
 		fsswi.asm fstime.asm fsuser.asm funlink.asm funload.asm
 
-ALLOBJS		= $(OS9P1) $(OS9P2)
+ALLOBJS		= $(KERNEL) $(KERNELP2)
 
 all:	$(ALLOBJS)
 
-$(OS9P1):	os9p1.asm $(SYSCALLS)
+$(KERNEL):	kernel.asm $(SYSCALLS)
 
-$(OS9P2):	os9p2.asm $(SYSCALLS)
+$(KERNELP2):	kernelp2.asm $(SYSCALLS)
 
 clean:
 	$(RM) $(ALLOBJS)
--- a/level2/modules/kernel/krn.asm	Fri Sep 26 17:54:49 2003 +0000
+++ b/level2/modules/kernel/krn.asm	Fri Sep 26 18:36:44 2003 +0000
@@ -1,17 +1,22 @@
 ********************************************************************
-* OS9p1 - OS-9 Level Two Kernel Part 1
+* Kernel - NitrOS-9 Level 2 Kernel
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-* 19r6   Assembles to the os9p1 module that works on    BGP 02/08/21
-*        my NitrOS-9 system
-* 19r7   Added check for CRC feature bit in init module BGP 02/09/26
-* 19r8   Back-ported to OS-9 Level Two                  BGP 02/09/26
+*  19r6    2002/08/21  Boisy G. Pitre
+* Assembles to the os9p1 module that works on my NitrOS-9 system.
+*
+*  19r7    2002/09/26  Boisy G. Pitre
+* Added check for CRC feature bit in init module
+*
+*  19r8    2003/09/22  Boisy G. Pitre
+* Back-ported to OS-9 Level Two.
 
-         nam   OS9p1
-         ttl   OS-9 Level Two Kernel Part 1
+         nam   Kernel
+         ttl   NitrOS-9 Level 2 Kernel
 
          IFP1
          use   defsfile
@@ -20,25 +25,24 @@
 * defines for customizations
 Revision set   8          module revision
 Edition  set   19         module Edition
-Where    equ   $F000      absolute address of where OS9p1 starts in memory
+Where    equ   $F000      absolute address of where Kernel starts in memory
 
          mod   eom,MName,Systm,ReEnt+Revision,OS9P1,0
 
-MName    fcs   /OS9p1/
+MName    fcs   /Kernel/
          fcb   Edition 
 
+* FILL - all unused bytes are now here
+         fcc   /www.katvixen.net/
          IFNE  H6309
-* FILL - all unused bytes are now here
-         fcc   /0123456789ABCDEF/
          fcc   /0123456789ABCDEF/
          fcc   /0123456789ABCDEF/
-         fcc   /01234/ 567/
+         fcc   /0/
          ELSE
-         fcc   /123456789ABCDEF/
-         fcc   /12345678/
+         fcc   /123/
          ENDC
 
-* Might as well have this here as just past the end of OS9p1...
+* Might as well have this here as just past the end of Kernel...
 DisTable fdb   L0CD2+Where   D.Clock absolute address at the start
          fdb   XSWI3+Where   D.XSWI3
          fdb   XSWI2+Where   D.XSWI2
@@ -47,7 +51,7 @@
          fdb   XSWI+Where    D.XSWI
          fdb   D.Crash       D.XNMI crash on an NMI
          fdb   $0055         D.ErrRst ??? Not used as far as I can tell
-         fdb   Sys.Vec+Where Initial OS9p1 system call vector
+         fdb   Sys.Vec+Where Initial Kernel system call vector
 DisSize  equ   *-DisTable
 * DO NOT ADD ANYTHING BETWEEN THESE 2 TABLES: see code using 'SubSiz', below
 LowSub   equ   $0160      start of low memory subroutines
@@ -185,7 +189,7 @@
          leax  >S.AltIRQ,pc    Setup alternate IRQ vector: pts to an RTS
          stx   <D.AltIRQ
 
-         lda   #'1        --- in OS9p1
+         lda   #'K        --- in Kernel
          jsr   <D.BtBug   ---
 
          leax  >S.Flip1,pc  Setup change to task 1 vector
@@ -309,7 +313,7 @@
 L01B8    os9   F$Boot      error linking init, try & load boot file
          bcc   L01B0       got it, try init again
          bra   L01CE       error, re-booting do D.Crash
 * Save pointer to init module and execute os9p2
 L01BF    stu   <D.Init     Save init module pointer
          lda   Feature1,u  Get feature byte #1 from init module
          bita  #CRCOn      CRC feature on?
@@ -318,13 +322,13 @@
 ShowI    lda   #'i         found init module
          jsr   <D.BtBug
 
-L01C1    leax  <os9p2,pc   Point to it's name
+L01C1    leax  <kernelp2,pc   Point to it's name
          bsr   link        Try to link it
          bcc   L01D0       It worked, execute it
          os9   F$Boot      It doesn't exist try re-booting
          bcc   L01C1       No error's, let's try to link it again
 L01CE    jmp   <D.Crash    obviously can't do it, crash machine
-L01D0    jmp   ,y          execute os9p2
+L01D0    jmp   ,y          execute kernelp2
 
 * Mark kernel in system memory map as used memory (256 byte blocks)
 L01D2    ldx   <D.SysMem   Get system mem ptr
@@ -346,7 +350,7 @@
          rts
 
 init     fcs   'Init'
-os9p2    fcs   'OS9p2'
+kernelp2 fcs   'KernelP2'
 
 * Service vector call pointers
 SysCalls fcb   F$Link
@@ -309,7 +313,7 @@
          bcc   L01B0       got it, try init again
          bra   L01CE       error, re-booting do D.Crash
-* Save pointer to init module and execute os9p2
+* Save pointer to init module and execute kernelp2
 L01BF    stu   <D.Init     Save init module pointer
          lda   Feature1,u  Get feature byte #1 from init module
--- a/level2/modules/kernel/krnp2.asm	Fri Sep 26 17:54:49 2003 +0000
+++ b/level2/modules/kernel/krnp2.asm	Fri Sep 26 18:36:44 2003 +0000
@@ -1,5 +1,5 @@
 ********************************************************************
 * OS9p2 - OS-9 Level Two Kernel Part 2
 *
 * $Id$
 *
@@ -57,8 +57,8 @@
 *
 * 18r6  Back-ported to OS-9 Level Two from NitrOS-9 Level Two
 
-         nam    OS9p2
-         ttl    OS-9 Level Two Kernel Part 2
+         nam    KernelP2
+         ttl    NitrOS-9 Level 2 Kernel Part 2
 
 ** If Network I/O ptrs are disabled, F$Fork runs 72 cycles faster
 Network  equ    0             Set to 1 to enable network I/O ptrs
@@ -72,9 +72,9 @@
 Revision equ    6
 *DAT.Free equ   $333E      --- remove this def later
 
-         mod    eom,MName,Systm,ReEnt+Revision,OS9P2,$0100
+         mod    eom,MName,Systm,ReEnt+Revision,KernelP2,$0100
 
-MName    fcs    /OS9p2/
+MName    fcs    /KernelP2/
          fcb    Edition
 
          ifeq   TC9-1
@@ -168,7 +168,7 @@
          puls   cc,u,pc     restore IRQ's, register stack pointer & return
      endc
 
-OS9P2    lda   #'2        into OS9p2
+KernelP2 lda   #'2        into KernelP2
          jsr   <D.BtBug
 
          leay   SvcTab,pc   install system calls
@@ -1,5 +1,5 @@
 ********************************************************************
-* OS9p2 - OS-9 Level Two Kernel Part 2
+* KernelP2 - NitrOS-9 Level 2 Kernel Part 2
 *
 * $Id$